const core = @import("core");
const std = @import("std");
const sys = @import("./sys.zig");

///
/// Starts the the game engine.
///
pub fn main() anyerror!void {
    return nosuspend await async sys.display(anyerror, run);
}

fn run(app: *sys.App, graphics: *sys.Graphics) anyerror!void {
    var gpa = std.heap.GeneralPurposeAllocator(.{}){};

    defer _ = gpa.deinit();

    {
        var file_access = try app.data.open(try sys.Path.joined(&.{"ona.lua"}), .readonly);

        defer file_access.close();

        const file_size = try file_access.queryLength();
        const allocator = gpa.allocator();
        const buffer = try allocator.alloc(u8, file_size);

        defer allocator.free(buffer);

        if ((try file_access.read(buffer)) != file_size) return error.ScriptLoadFailure;

        app.log(.debug, buffer);
    }

    while (graphics.poll()) |_| {
        graphics.present();
    }
}

test {
    _ = sys;
}
